@@ -16,4 +16,14 @@
         df[[i]] = factor(df[[i]])
   df
 }
-# attention because order of factors is lost ...
\ No newline at end of file
+# attention because order of factors is lost ...
+
+# Function to calculate the coefficient of variance
+cv <- function(x){
+  sd(x)/mean(x)
+}
+
+# Function to select only positive values
+isPositive <- function(x){
+  x >= 0
+}
\ No newline at end of file
